<?php

namespace Litecms\BinaryCommission\Http\Controllers;

use App\Http\Controllers\ResourceController as BaseController;
use Form;
use Litecms\BinaryCommission\Http\Requests\BinaryCommissionRequest;
use Litecms\BinaryCommission\Interfaces\BinaryCommissionRepositoryInterface;
use Litecms\BinaryCommission\Models\BinaryCommission;

/**
 * Resource controller class for binary_commission.
 */
class BinaryCommissionResourceController extends BaseController
{

    /**
     * Initialize binary_commission resource controller.
     *
     * @param type BinaryCommissionRepositoryInterface $binary_commission
     *
     * @return null
     */
    public function __construct(BinaryCommissionRepositoryInterface $binary_commission)
    {
        parent::__construct();
        $this->repository = $binary_commission;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Litecms\BinaryCommission\Repositories\Criteria\BinaryCommissionResourceCriteria::class);
    }

    /**
     * Display a list of binary_commission.
     *
     * @return Response
     */
    public function index(BinaryCommissionRequest $request)
    {
        $view = $this->response->theme->listView();

        if ($this->response->typeIs('json')) {
            $function = camel_case('get-' . $view);
            return $this->repository
                ->setPresenter(\Litecms\BinaryCommission\Repositories\Presenter\BinaryCommissionPresenter::class)
                ->$function();
        }

        $binary_commissions = $this->repository->paginate();

        return $this->response->title(trans('binary_commission::binary_commission.names'))
            ->view('binary_commission::binary_commission.index', true)
            ->data(compact('binary_commissions'))
            ->output();
    }

    /**
     * Display binary_commission.
     *
     * @param Request $request
     * @param Model   $binary_commission
     *
     * @return Response
     */
    public function show(BinaryCommissionRequest $request, BinaryCommission $binary_commission)
    {

        if ($binary_commission->exists) {
            $view = 'binary_commission::binary_commission.show';
        } else {
            $view = 'binary_commission::binary_commission.new';
        }

        return $this->response->title(trans('app.view') . ' ' . trans('binary_commission::binary_commission.name'))
            ->data(compact('binary_commission'))
            ->view($view, true)
            ->output();
    }

    /**
     * Show the form for creating a new binary_commission.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(BinaryCommissionRequest $request)
    {

        $binary_commission = $this->repository->newInstance([]);
        return $this->response->title(trans('app.new') . ' ' . trans('binary_commission::binary_commission.name')) 
            ->view('binary_commission::binary_commission.create', true) 
            ->data(compact('binary_commission'))
            ->output();
    }

    /**
     * Create new binary_commission.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(BinaryCommissionRequest $request)
    {
        try {
            $attributes              = $request->all();
            $attributes['user_id']   = user_id();
            $attributes['user_type'] = user_type();
            $binary_commission                 = $this->repository->create($attributes);

            return $this->response->message(trans('messages.success.created', ['Module' => trans('binary_commission::binary_commission.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('binary_commission/binary_commission/' . $binary_commission->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/binary_commission/binary_commission'))
                ->redirect();
        }

    }

    /**
     * Show binary_commission for editing.
     *
     * @param Request $request
     * @param Model   $binary_commission
     *
     * @return Response
     */
    public function edit(BinaryCommissionRequest $request, BinaryCommission $binary_commission)
    {
        return $this->response->title(trans('app.edit') . ' ' . trans('binary_commission::binary_commission.name'))
            ->view('binary_commission::binary_commission.edit', true)
            ->data(compact('binary_commission'))
            ->output();
    }

    /**
     * Update the binary_commission.
     *
     * @param Request $request
     * @param Model   $binary_commission
     *
     * @return Response
     */
    public function update(BinaryCommissionRequest $request, BinaryCommission $binary_commission)
    {
        try {
            $attributes = $request->all();

            $binary_commission->update($attributes);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('binary_commission::binary_commission.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('binary_commission/binary_commission/' . $binary_commission->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('binary_commission/binary_commission/' . $binary_commission->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the binary_commission.
     *
     * @param Model   $binary_commission
     *
     * @return Response
     */
    public function destroy(BinaryCommissionRequest $request, BinaryCommission $binary_commission)
    {
        try {

            $binary_commission->delete();
            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('binary_commission::binary_commission.name')]))
                ->code(202)
                ->status('success')
                ->url(guard_url('binary_commission/binary_commission/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('binary_commission/binary_commission/' . $binary_commission->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove multiple binary_commission.
     *
     * @param Model   $binary_commission
     *
     * @return Response
     */
    public function delete(BinaryCommissionRequest $request, $type)
    {
        try {
            $ids = hashids_decode($request->input('ids'));

            if ($type == 'purge') {
                $this->repository->purge($ids);
            } else {
                $this->repository->delete($ids);
            }

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('binary_commission::binary_commission.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('binary_commission/binary_commission'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/binary_commission/binary_commission'))
                ->redirect();
        }

    }

    /**
     * Restore deleted binary_commissions.
     *
     * @param Model   $binary_commission
     *
     * @return Response
     */
    public function restore(BinaryCommissionRequest $request)
    {
        try {
            $ids = hashids_decode($request->input('ids'));
            $this->repository->restore($ids);

            return $this->response->message(trans('messages.success.restore', ['Module' => trans('binary_commission::binary_commission.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('/binary_commission/binary_commission'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/binary_commission/binary_commission/'))
                ->redirect();
        }

    }

}
