<?php

namespace Litecms\BinaryCommission\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litecms\BinaryCommission\Models\BinaryCommission;

class BinaryCommissionPolicy
{

    /**
     * Determine if the given user can view the binary_commission.
     *
     * @param UserPolicy $user
     * @param BinaryCommission $binary_commission
     *
     * @return bool
     */
    public function view(UserPolicy $user, BinaryCommission $binary_commission)
    {
        if ($user->canDo('binary_commission.binary_commission.view') && $user->isAdmin()) {
            return true;
        }

        return $binary_commission->user_id == user_id() && $binary_commission->user_type == user_type();
    }

    /**
     * Determine if the given user can create a binary_commission.
     *
     * @param UserPolicy $user
     * @param BinaryCommission $binary_commission
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('binary_commission.binary_commission.create');
    }

    /**
     * Determine if the given user can update the given binary_commission.
     *
     * @param UserPolicy $user
     * @param BinaryCommission $binary_commission
     *
     * @return bool
     */
    public function update(UserPolicy $user, BinaryCommission $binary_commission)
    {
        if ($user->canDo('binary_commission.binary_commission.edit') && $user->isAdmin()) {
            return true;
        }

        return $binary_commission->user_id == user_id() && $binary_commission->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given binary_commission.
     *
     * @param UserPolicy $user
     * @param BinaryCommission $binary_commission
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, BinaryCommission $binary_commission)
    {
        return $binary_commission->user_id == user_id() && $binary_commission->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given binary_commission.
     *
     * @param UserPolicy $user
     * @param BinaryCommission $binary_commission
     *
     * @return bool
     */
    public function verify(UserPolicy $user, BinaryCommission $binary_commission)
    {
        if ($user->canDo('binary_commission.binary_commission.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given binary_commission.
     *
     * @param UserPolicy $user
     * @param BinaryCommission $binary_commission
     *
     * @return bool
     */
    public function approve(UserPolicy $user, BinaryCommission $binary_commission)
    {
        if ($user->canDo('binary_commission.binary_commission.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
