<?php

namespace Litecms\BinaryCommission\Providers;

use Illuminate\Support\ServiceProvider;

class BinaryCommissionServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'binary_commission');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'binary_commission');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        // Bind facade
        $this->app->bind('litecms.binary_commission', function ($app) {
            return $this->app->make('Litecms\BinaryCommission\BinaryCommission');
        });

                // Bind BinaryCommission to repository
        $this->app->bind(
            'Litecms\BinaryCommission\Interfaces\BinaryCommissionRepositoryInterface',
            \Litecms\BinaryCommission\Repositories\Eloquent\BinaryCommissionRepository::class
        );

        $this->app->register(\Litecms\BinaryCommission\Providers\AuthServiceProvider::class);
        
        $this->app->register(\Litecms\BinaryCommission\Providers\RouteServiceProvider::class);
                
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['litecms.binary_commission'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('litecms/binary_commission.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/binary_commission')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/binary_commission')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
